@@ -15,7 +15,7 @@ import ifaddr
 from RangeHTTPServer import RangeRequestHandler
 
 from soco_cli.utils import (
-    error_and_exit,
+    error_report,
     event_unsubscribe,
     set_sigterm,
     set_speaker_playing_local_file,
@@ -27,7 +27,8 @@ PORT_END = 54099
 
 SUPPORTED_TYPES = ["MP3", "M4A", "MP4", "FLAC", "OGG", "WMA", "WAV", "AAC"]
 
-PY37PLUS = True if pyversion.major >= 3 and pyversion.minor >= 7 else False
+# Need to know whether this is Python >= 3.7
+PY37PLUS = bool((pyversion.major == 3 and pyversion.minor >= 7) or pyversion.major > 3)
 
 
 class ThreadedHTTPServer(ThreadingMixIn, HTTPServer):
@@ -84,7 +85,6 @@ class MyHTTPHandler(RangeRequestHandler):
         except Exception as e:
             # It's normal to hit some exceptions with Sonos.
             logging.info("Exception ignored: {}".format(e))
-            pass
 
     def log_message(self, format, *args):
         # Suppress HTTP logging
@@ -114,8 +114,7 @@ def http_server(server_ip, directory, filename, speaker_ips):
         except OSError:
             # Assume this means that the port is in use
             continue
-    else:
-        return None
+    return None
 
 
 def get_server_ip(speaker):
@@ -130,8 +129,7 @@ def get_server_ip(speaker):
                 )
                 if IPv4Address(speaker.ip_address) in network:
                     return ip.ip
-    else:
-        return None
+    return None
 
 
 def wait_until_stopped(speaker, uri, aac_file=False):
@@ -170,8 +168,7 @@ def wait_until_stopped(speaker, uri, aac_file=False):
                         event_unsubscribe(sub)
                         speaker.stop()
                         return True
-                    else:
-                        logging.info("AAC: transition event before playback")
+                    logging.info("AAC: transition event before playback")
                 if event.variables["transport_state"] == "PLAYING":
                     has_played = True
                     logging.info("AAC: has_played set to True")
@@ -188,12 +185,11 @@ def wait_until_stopped(speaker, uri, aac_file=False):
 
 def is_supported_type(filename):
     file_upper = filename.upper()
-    for type in SUPPORTED_TYPES:
-        if file_upper.endswith("." + type):
+    for file_type in SUPPORTED_TYPES:
+        if file_upper.endswith("." + file_type):
             # Supported file type
             return True
-    else:
-        return False
+    return False
 
 
 def play_local_file(speaker, pathname):
@@ -201,13 +197,13 @@ def play_local_file(speaker, pathname):
     # pathname is the local file to be played
 
     if not path.exists(pathname):
-        error_and_exit("File '{}' not found".format(pathname))
+        error_report("File '{}' not found".format(pathname))
         return False
 
     directory, filename = path.split(pathname)
 
     if not is_supported_type(filename):
-        error_and_exit(
+        error_report(
             "Unsupported file type; must be one of: {}".format(SUPPORTED_TYPES)
         )
         return False
@@ -217,7 +213,7 @@ def play_local_file(speaker, pathname):
 
     server_ip = get_server_ip(speaker)
     if not server_ip:
-        error_and_exit("Can't determine an IP address for web server")
+        error_report("Can't determine an IP address for web server")
         return False
     logging.info("Using server IP address: {}".format(server_ip))
 
@@ -227,7 +223,7 @@ def play_local_file(speaker, pathname):
         speaker_ips.append(zone.ip_address)
     httpd = http_server(server_ip, directory, url_filename, speaker_ips)
     if not httpd:
-        error_and_exit("Cannot create HTTP server")
+        error_report("Cannot create HTTP server")
         return False
 
     # This ensures that other running invocations of 'play_file'
